.. image:: https://img.shields.io/pypi/v/django-otp-messagebird?color=blue
   :target: https://pypi.org/project/django-otp-messagebird/
   :alt: PyPI
.. image:: https://img.shields.io/readthedocs/django-otp-messagebird
   :target: https://django-otp-messagebird.readthedocs.io/
   :alt: Documentation
.. image:: https://img.shields.io/badge/github-django--otp--messagebird-green
   :target: https://github.com/arjan-s/django-otp-messagebird
   :alt: Source

This is a django-otp plugin that delivers tokens via MessageBird's `SMS
<https://messagebird.com/en/sms/>`_ service.

See `django-otp <https://pypi.org/project/django-otp>`_ for more information
on the OTP framework.
